@@ -3,7 +3,7 @@
 extern crate test;
 
 use {
-    solana_perf::{packet::PacketsRecycler, recycler::Recycler},
+    solana_perf::{packet::PacketBatchRecycler, recycler::Recycler},
     test::Bencher,
 };
 
@@ -11,7 +11,7 @@ use {
 fn bench_recycler(bencher: &mut Bencher) {
     solana_logger::setup();
 
-    let recycler: PacketsRecycler = Recycler::default();
+    let recycler: PacketBatchRecycler = Recycler::default();
 
     for _ in 0..1000 {
         let _packet = recycler.allocate("");
